==> prometheus-annotations-2.11.5-sources.jar: io/dekorate/prometheus/config/ServiceMonitorConfigBuilder.java <==
package io.dekorate.prometheus.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ServiceMonitorConfigBuilder extends ServiceMonitorConfigFluentImpl<ServiceMonitorConfigBuilder> implements VisitableBuilder<io.dekorate.prometheus.config.ServiceMonitorConfig,io.dekorate.prometheus.config.ServiceMonitorConfigBuilder>{
  public ServiceMonitorConfigBuilder() {
    this(false);
  }
  public ServiceMonitorConfigBuilder(Boolean validationEnabled) {
    this(new ServiceMonitorConfig(), validationEnabled);
  }
  public ServiceMonitorConfigBuilder(ServiceMonitorConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceMonitorConfigBuilder(io.dekorate.prometheus.config.ServiceMonitorConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceMonitorConfig(), validationEnabled);
  }
  public ServiceMonitorConfigBuilder(io.dekorate.prometheus.config.ServiceMonitorConfigFluent<?> fluent,io.dekorate.prometheus.config.ServiceMonitorConfig instance) {
    this(fluent, instance, false);
  }
  public ServiceMonitorConfigBuilder(io.dekorate.prometheus.config.ServiceMonitorConfigFluent<?> fluent,io.dekorate.prometheus.config.ServiceMonitorConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProject(instance.getProject()); 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withPort(instance.getPort()); 
    fluent.withPath(instance.getPath()); 
    fluent.withInterval(instance.getInterval()); 
    fluent.withHonorLabels(instance.getHonorLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceMonitorConfigBuilder(io.dekorate.prometheus.config.ServiceMonitorConfig instance) {
    this(instance,false);
  }
  public ServiceMonitorConfigBuilder(io.dekorate.prometheus.config.ServiceMonitorConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withPort(instance.getPort()); 
    this.withPath(instance.getPath()); 
    this.withInterval(instance.getInterval()); 
    this.withHonorLabels(instance.getHonorLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.prometheus.config.ServiceMonitorConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public EditableServiceMonitorConfig build() {
    EditableServiceMonitorConfig buildable = new EditableServiceMonitorConfig(fluent.getProject(),fluent.getAttributes(),fluent.getPort(),fluent.getPath(),fluent.getInterval(),fluent.getHonorLabels());
    return buildable;
  }
  
}

==> prometheus-annotations-3.7.4-sources.jar: io/dekorate/prometheus/config/ServiceMonitorConfigBuilder.java <==
package io.dekorate.prometheus.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ServiceMonitorConfigBuilder extends ServiceMonitorConfigFluentImpl<ServiceMonitorConfigBuilder> implements VisitableBuilder<ServiceMonitorConfig,ServiceMonitorConfigBuilder>{
  public ServiceMonitorConfigBuilder() {
    this(false);
  }
  public ServiceMonitorConfigBuilder(Boolean validationEnabled) {
    this(new ServiceMonitorConfig(), validationEnabled);
  }
  public ServiceMonitorConfigBuilder(ServiceMonitorConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceMonitorConfigBuilder(ServiceMonitorConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServiceMonitorConfig(), validationEnabled);
  }
  public ServiceMonitorConfigBuilder(ServiceMonitorConfigFluent<?> fluent,ServiceMonitorConfig instance) {
    this(fluent, instance, false);
  }
  public ServiceMonitorConfigBuilder(ServiceMonitorConfigFluent<?> fluent,ServiceMonitorConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProject(instance.getProject()); 
    fluent.withAttributes(instance.getAttributes()); 
    fluent.withPort(instance.getPort()); 
    fluent.withPath(instance.getPath()); 
    fluent.withInterval(instance.getInterval()); 
    fluent.withHonorLabels(instance.getHonorLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceMonitorConfigBuilder(ServiceMonitorConfig instance) {
    this(instance,false);
  }
  public ServiceMonitorConfigBuilder(ServiceMonitorConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withProject(instance.getProject()); 
    this.withAttributes(instance.getAttributes()); 
    this.withPort(instance.getPort()); 
    this.withPath(instance.getPath()); 
    this.withInterval(instance.getInterval()); 
    this.withHonorLabels(instance.getHonorLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  ServiceMonitorConfigFluent<?> fluent;
  Boolean validationEnabled;
  public EditableServiceMonitorConfig build() {
    EditableServiceMonitorConfig buildable = new EditableServiceMonitorConfig(fluent.getProject(),fluent.getAttributes(),fluent.getPort(),fluent.getPath(),fluent.getInterval(),fluent.getHonorLabels());
    return buildable;
  }
  
}
